%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Function name : KmeansClustering
% Description : clustering using K-means algorithm
%
% Input : - data -> data that will be clustered
%         - k -> number of clusters
%         - centroids -> initial centroids (optional)
% Output : clusters  -> clustering result
%          centroids  -> centroids of clustering result
%
% Example : [clusters,centroids]=KmeansClustering(data,k,centroids)
%
% 2006 (c) Ali Ridho Barakbah (ridho@eepis-its.edu)
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

function [clusters,centroids]=KmeansClustering(data,k,centroids)

totaldata=size(data,1);
cols=size(data,2);
minvalues=min(data);
maxvalues=max(data);

if (nargin<3)
    centroids=[];
    for i=1:k
        for j=1:cols
            centroids(i,j)=rand*maxvalues(j)+minvalues(j);
        end
    end
end

clusters=zeros(totaldata,1);
selisih=1;
while (selisih~=0)
    for i=1:totaldata
        jarak=getDistance(data(i,:),centroids);
        [jarakmin,posmin]=min(jarak);
        clusters(i)=posmin;
    end
    salah=0;
    for p=1:k
        if size(find(clusters==p),1)==0
            salah=1; break
        end
    end
    if (salah==1)
        break
    end
    oldcentroids=centroids;
    for p=1:k
        centroids(p,:)=mean(data(find(clusters==p),:),1);
    end
    
    selisih=min(min(centroids-oldcentroids));
end

if (salah==1)
    if (nargin<3)
        [clusters,centroids]=KmeansClustering(data,k);   
    end
end
