% Deskripsi : untuk melakukan mutasi
% Input : probMut = probabilitas mutasi
%         anak = sekumpulan anak dalam populasi
%         jenisMut = jenis operasi mutasi yang dipakai
%                    (0 = inverse (untuk biner),
%                     1 = aritmatik,
%                     2 = geser tertentu,
%                     3 = geser random)
%         minval = nilai minimal pada setiap dimensi
%         maxval = nilai maksimal pada setiap dimensi
%         nilaigeser = nilai pergeseran pada jenis mutasi geser
% Output : anakbaru = anak yang dihasilkan dari proses mutasi
%
% 2006 (c) Machine Learning Team
% Politeknik Elektronika Negeri Surabaya - ITS
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

function anakbaru=Mutation(probMut, anak, jenisMut, minval, maxval, nilaigeser)

if (nargin<4) nilaigeser=0; end
e=0.1;

jumlahanak=size(anak,1);
jumlahgen=size(anak,2);
anakbaru=anak;
for i=1:jumlahanak
    k1=floor(jumlahgen*rand)+1;
    k2=floor((jumlahgen-k1)*rand)+k1;
    for j=k1:k2
        p=rand;
        if(p<probMut)
            switch jenisMut
                case 0
                    anakbaru(i,j)=1-anak(i,j);
                case 1
                    anakbaru(i,j)=anak(i,j)-e*rand-0.5*e; %-0.05 - 0.05
                case 2
                    sign=rand-0.5;
                    if (sign<0) sign=-1; else sign=1; end
                    anakbaru(i,j)=anak(i,j)+sign*nilaigeser;
                    if (anakbaru(i,j)<minval(j)) anakbaru(i,j)=maxval(j); end
                    if (anakbaru(i,j)>maxval(j)) anakbaru(i,j)=minval(j); end
                                        
                case 3
                    nilaigeser=rand*(maxval(j)-minval(j))+minval(j);
                    sign=rand-0.5;
                    if (sign<0) sign=-1; else sign=1; end
                    anakbaru(i,j)=anak(i,j)+sign*nilaigeser;
                    if (anakbaru(i,j)<minval(j)) anakbaru(i,j)=maxval(j); end
                    if (anakbaru(i,j)>maxval(j)) anakbaru(i,j)=minval(j); end
            end
        end
    end
end