%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Function name : initLocalRandomPoints
% Input : - maxScalePerCluster -> maximum scale per cluster (default=5)
%         - maxPointsPerCluster -> maximum number of points per cluster (default=10)
% Output : - Points -> clustering data
%          - totalcluster -> number of clusters
% 
% Description : to generate initial local random data distribution
% {The point centers will be determined in 9 positions:
% (20,20), (50,20), (80,20),
% (20,50), (50,50), (80,50),
% (20,80), (50,80), (80,80)}
%
% 2004 (C) Ali Ridho Barakbah (ridho@eepis-its.edu)
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


function [Points,totalcluster]=initLocalRandomPoints(maxScalePerCluster,maxPointsPerCluster)

global Points;
global maxscalepercluster;
global maxPointspercluster;

Points=[];
if (nargin<1) maxscalepercluster=5; else maxscalepercluster=maxScalePerCluster; end
if (nargin<2) maxPointspercluster=10; else maxPointspercluster=maxPointsPerCluster; end

ttl=0;
if(round(rand)==0)
    Points=createCluster(50,50);
    ttl=ttl+1;
end
if(round(rand)==0)
    Points=cat(1,Points,createCluster(20,20));
    ttl=ttl+1;
end
if(round(rand)==0)
    Points=cat(1,Points,createCluster(50,20));
    ttl=ttl+1;
end
if(round(rand)==0)
    Points=cat(1,Points,createCluster(80,20));
    ttl=ttl+1;
end
if(round(rand)==0)
    Points=cat(1,Points,createCluster(20,50));
    ttl=ttl+1;
end
if(round(rand)==0)
    Points=cat(1,Points,createCluster(80,50));
    ttl=ttl+1;
end
if(round(rand)==0)
    Points=cat(1,Points,createCluster(20,80));
    ttl=ttl+1;
end
if(round(rand)==0)
    Points=cat(1,Points,createCluster(50,80));
    ttl=ttl+1;
end
if(round(rand)==0)
    Points=cat(1,Points,createCluster(80,80));
    ttl=ttl+1;
end

totalcluster=ttl;


%Function to create clustering data
function Data=createCluster(x,y)


global maxscalepercluster;
global maxPointspercluster;

center=[x y];

%totalpoint=round(rand(1)*maxPointspercluster);
totalpoint=maxPointspercluster;
while (totalpoint<6)
    totalpoint=round(rand(1)*maxPointspercluster);
end

Points=round(rand(totalpoint,2)*maxscalepercluster);

for i=1:size(Points,1)
    for j=1:size(Points,2)
        if (round(rand))
            if (j==1)
                Points(i,j)=center(1)-Points(i,j);    
            else
                Points(i,j)=center(2)-Points(i,j);    
            end
        else
            if(j==1)
                Points(i,j)=center(1)+Points(i,j);
            else
                Points(i,j)=center(2)+Points(i,j);
            end
        end
    end
end

Data=Points;
